@@ -22,9 +22,9 @@ def executeCommand(pump, command, waitForPump=False):
     if pump.checkValidity(command):
         sendCommand(pump.asciiAddress, command, waitForPump)
 
-def definePump(address: str, type: util.PSDTypes, baudRate=9600, resolutionMode=0):
+def definePump(address: str, type: util.PSDTypes):
     if len(pumps) < pumpLength:
-        newPump = PSD(address, type, baudRate, resolutionMode)
+        newPump = PSD(address, type)
         print("Enable h Factor Commands and Queries")
         sendCommand(newPump.asciiAddress, newPump.command.enableHFactorCommandsAndQueries() + newPump.command.executeCommandBuffer())
         result = sendCommand(newPump.asciiAddress, newPump.command.syringeModeQuery(), True)
