@@ -10,7 +10,7 @@ statusBytesInfo = {
     '`': "Pump is ready - no error",
     'a': "Initialization error – occurs when the pump fails to initialize",
     'b': "Invalid command – occurs when an unrecognized command is used.",
-    'c': "Invalid operand – occurs when and invalid parameter is given with a command.",
+    'c': "Invalid operand – occurs when an invalid parameter is given with a command.",
     'd': "Invalid command sequence – occurs when the command communication protocol is incorrect",
     'f': "EEPROM failure – occurs when the EEPROM is faulty",
     'g': "Syringe not initialized – occurs when the syringe fails to initialize",
