@@ -28,15 +28,6 @@ class QueryCommandsEnumeration(Enum):
     SYRINGE_DIAGNOSTIC_TIMER_VALUE = '?38000'
 
 
-class PositionInShortestDirection(Enum):
-    INPUT = 1
-    OUTPUT = 2
-    WASH = 3
-    RETURN = 4
-    BYPASS = 5
-    EXTRA = 6
-
-
 class PSDTypes(Enum):
     psd4 = '4'
     psd6 = '6'
